package com.fs.sop.service.impl;


import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fs.sop.domain.QwSopLogsDetalis;
import com.fs.sop.mapper.QwSopLogsDetalisMapper;
import com.fs.sop.service.IQwSopLogsDetalisService;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * qwSopLogsDetalisService业务层处理
 *
 * @author fs
 * @date 2025-02-04
 */
@Service
public class QwSopLogsDetalisServiceImpl extends ServiceImpl<QwSopLogsDetalisMapper, QwSopLogsDetalis> implements IQwSopLogsDetalisService {

    /**
     * 查询qwSopLogsDetalis
     *
     * @param id qwSopLogsDetalis主键
     * @return qwSopLogsDetalis
     */
    @Override
    public QwSopLogsDetalis selectQwSopLogsDetalisById(Long id)
    {
        return baseMapper.selectQwSopLogsDetalisById(id);
    }

    /**
     * 查询qwSopLogsDetalis列表
     *
     * @param qwSopLogsDetalis qwSopLogsDetalis
     * @return qwSopLogsDetalis
     */
    @Override
    public List<QwSopLogsDetalis> selectQwSopLogsDetalisList(QwSopLogsDetalis qwSopLogsDetalis)
    {
        return baseMapper.selectQwSopLogsDetalisList(qwSopLogsDetalis);
    }

    /**
     * 新增qwSopLogsDetalis
     *
     * @param qwSopLogsDetalis qwSopLogsDetalis
     * @return 结果
     */
    @Override
    public int insertQwSopLogsDetalis(QwSopLogsDetalis qwSopLogsDetalis)
    {
        return baseMapper.insertQwSopLogsDetalis(qwSopLogsDetalis);
    }

    /**
     * 修改qwSopLogsDetalis
     *
     * @param qwSopLogsDetalis qwSopLogsDetalis
     * @return 结果
     */
    @Override
    public int updateQwSopLogsDetalis(QwSopLogsDetalis qwSopLogsDetalis)
    {
        return baseMapper.updateQwSopLogsDetalis(qwSopLogsDetalis);
    }

    /**
     * 批量删除qwSopLogsDetalis
     *
     * @param ids 需要删除的qwSopLogsDetalis主键
     * @return 结果
     */
    @Override
    public int deleteQwSopLogsDetalisByIds(Long[] ids)
    {
        return baseMapper.deleteQwSopLogsDetalisByIds(ids);
    }

    /**
     * 删除qwSopLogsDetalis信息
     *
     * @param id qwSopLogsDetalis主键
     * @return 结果
     */
    @Override
    public int deleteQwSopLogsDetalisById(Long id)
    {
        return baseMapper.deleteQwSopLogsDetalisById(id);
    }
}
